Documentation
¶
Index ¶
- Variables
- func CampaignSentAtFormat(d time.Time) string
- type AbortCampaignRequest
- type ActivateTriggeredCampaignRequest
- type BulkEventsResponse
- type BulkUpdateRequest
- type BulkUpdateResponse
- type BulkUpdateUser
- type BulkUserUpdateSubscriptionsRequest
- type BulkUserUpdateSubscriptionsResponse
- type Campaign
- type CampaignsResponse
- type CancelCampaignRequest
- type CatalogFieldMapping
- type Catalogs
- type Channel
- type ChannelsResponse
- type CreateCampaignRequest
- type CreateCampaignResponse
- type Event
- type EventTrackBulkRequest
- type EventTrackRequest
- type EventsResponse
- type FailedEventUpdates
- type FailedUpdates
- type FrequencyCap
- type GdprRequest
- type List
- type ListCreateRequest
- type ListCreateResponse
- type ListSubscribeRequest
- type ListSubscribeResponse
- type ListSubscriber
- type ListUnSubscribeRequest
- type ListUnSubscribeResponse
- type ListUnSubscriber
- type ListsResponse
- type MessageType
- type MessageTypeResponse
- type PostResponse
- type TriggerCampaignRequest
- type User
- type UserFieldsResponse
- type UserForgottenEmailsResponse
- type UserRequest
- type UserResponse
- type UserSentMessage
- type UserSentMessagesRequest
- type UserSentMessagesResponse
- type UserUpdateEmailRequest
- type UserUpdateSubscriptionsRequest
Constants ¶
This section is empty.
Variables ¶
var CampaignSendMode = camSendMode{}
Functions ¶
func CampaignSentAtFormat ¶
Types ¶
type AbortCampaignRequest ¶
type AbortCampaignRequest = campaignId
type ActivateTriggeredCampaignRequest ¶
type ActivateTriggeredCampaignRequest = campaignId
type BulkEventsResponse ¶
type BulkEventsResponse struct {
SuccessCount int64 `json:"successCount"`
FailCount int64 `json:"failCount"`
DisallowedEventNames []string `json:"disallowedEventNames"`
FilteredOutFields []string `json:"filteredOutFields"`
CreatedFields []string `json:"createdFields"`
FailedUpdates FailedEventUpdates `json:"failedUpdates"`
}
type BulkUpdateRequest ¶
type BulkUpdateRequest struct {
Users []BulkUpdateUser `json:"users"`
CreateNewFields *bool `json:"createNewFields,omitempty"`
}
type BulkUpdateResponse ¶
type BulkUpdateResponse struct {
SuccessCount int64 `json:"successCount"`
FailCount int64 `json:"failCount"`
FailedUpdates FailedUpdates `json:"failedUpdates"`
FilteredOutFields []string `json:"filteredOutFields"`
CreatedFields []string `json:"createdFields"`
}
type BulkUpdateUser ¶
type BulkUserUpdateSubscriptionsRequest ¶
type BulkUserUpdateSubscriptionsRequest struct {
UpdateSubscriptionsRequests []UserUpdateSubscriptionsRequest `json:"updateSubscriptionsRequests"`
}
type BulkUserUpdateSubscriptionsResponse ¶
type BulkUserUpdateSubscriptionsResponse struct {
SuccessCount int64 `json:"successCount"`
FailCount int64 `json:"failCount"`
InvalidEmails []string `json:"invalidEmails"`
InvalidUserIds []string `json:"invalidUserIds"`
ValidEmailFailures []string `json:"validEmailFailures"`
ValidUserIdFailures []string `json:"validUserIdFailures"`
}
type Campaign ¶
type Campaign struct {
Id int64 `json:"id"`
CreatedAt int64 `json:"createdAt"`
UpdatedAt int64 `json:"updatedAt"`
StartAt int64 `json:"startAt,omitempty"`
EndedAt int64 `json:"endedAt,omitempty"`
Name string `json:"name"`
TemplateId int64 `json:"templateId,omitempty"`
MessageMedium string `json:"messageMedium"`
CreatedByUserId string `json:"createdByUserId"`
UpdatedByUserId string `json:"updatedByUserId,omitempty"`
CampaignState string `json:"campaignState"`
ListIds []int64 `json:"listIds,omitempty"`
SuppressionListIds []int64 `json:"suppressionListIds,omitempty"`
SendSize int64 `json:"sendSize,omitempty"`
RecurringCampaignId int64 `json:"recurringCampaignId,omitempty"`
WorkflowId int64 `json:"workflowId,omitempty"`
Labels []string `json:"labels,omitempty"`
Type string `json:"type"`
}
type CampaignsResponse ¶
type CampaignsResponse struct {
Campaigns []Campaign `json:"campaigns"`
}
type CancelCampaignRequest ¶
type CancelCampaignRequest = campaignId
type CatalogFieldMapping ¶
type ChannelsResponse ¶
type ChannelsResponse struct {
Channels []Channel `json:"channels"`
}
type CreateCampaignRequest ¶
type CreateCampaignRequest struct {
Name string `json:"name"`
ListIds []int64 `json:"listIds"`
TemplateId int64 `json:"templateId"`
SuppressionListIds []int64 `json:"suppressionListIds"`
SendAt string `json:"sendAt"`
SendMode string `json:"sendMode"`
StartTimeZone string `json:"startTimeZone"`
DefaultTimeZone string `json:"defaultTimeZone"`
DataFields map[string]any `json:"dataFields"`
}
type CreateCampaignResponse ¶
type CreateCampaignResponse = campaignId
type Event ¶
type Event struct {
EventName string `json:"eventName"`
Email string `json:"email"`
CreatedAt string `json:"createdAt"`
EventUpdatedAt string `json:"eventUpdatedAt"`
ItblInternal map[string]interface{} `json:"itblInternal"`
EventType string `json:"eventType"`
DataFields map[string]interface{} `json:"dataFields"`
}
type EventTrackBulkRequest ¶
type EventTrackBulkRequest struct {
Events []EventTrackRequest `json:"events"`
}
type EventTrackRequest ¶
type EventTrackRequest struct {
Email string `json:"email,omitempty"`
UserId string `json:"userId,omitempty"`
EventName string `json:"eventName"`
Id string `json:"id,omitempty"`
CreatedAt int64 `json:"createdAt"`
DataFields map[string]interface{} `json:"dataFields"`
CampaignId int64 `json:"campaignId,omitempty"`
TemplateId int64 `json:"templateId,omitempty"`
CreateNewFields *bool `json:"createNewFields,omitempty"`
}
type EventsResponse ¶
type EventsResponse struct {
Events []Event `json:"events"`
}
type FailedEventUpdates ¶
type FailedEventUpdates struct {
InvalidEmails []string `json:"invalidEmails"`
InvalidUserIds []string `json:"invalidUserIds"`
NotFoundEmails []string `json:"notFoundEmails"`
NotFoundUserIds []string `json:"notFoundUserIds"`
ForgottenEmails []string `json:"forgottenEmails"`
ForgottenUserIds []string `json:"forgottenUserIds"`
}
type FailedUpdates ¶
type FailedUpdates struct {
ConflictEmails []string `json:"conflictEmails"`
ConflictUserIds []string `json:"conflictUserIds"`
ForgottenEmails []string `json:"forgottenEmails"`
ForgottenUserIds []string `json:"forgottenUserIds"`
InvalidDataEmails []string `json:"invalidDataEmails"`
InvalidDataUserIds []string `json:"invalidDataUserIds"`
InvalidEmails []string `json:"invalidEmails"`
InvalidUserIds []string `json:"invalidUserIds"`
NotFoundEmails []string `json:"notFoundEmails"`
NotFoundUserIds []string `json:"notFoundUserIds"`
}
type FrequencyCap ¶
type GdprRequest ¶
type ListCreateRequest ¶
type ListCreateResponse ¶
type ListCreateResponse struct {
ListId int64 `json:"listId"`
}
type ListSubscribeRequest ¶
type ListSubscribeRequest struct {
ListId int64 `json:"listId"`
Subscribers []ListSubscriber `json:"subscribers"`
// Whether to skip operation when the request includes a userId or email
// that doesn't yet exist in the Iterable project.
// When true, Iterable ignores requests with unknown userIds and email addresses.
// When false, Iterable creates new users.
// Only respected in API calls for userID-based and hybrid projects.
// Defaults to false.
UpdateExistingUsersOnly bool `json:"updateExistingUsersOnly,omitempty"`
}
type ListSubscribeResponse ¶
type ListSubscribeResponse struct {
SuccessCount int64 `json:"successCount"`
FailCount int64 `json:"failCount"`
FailedUpdates FailedUpdates `json:"failedUpdates"`
FilteredOutFields []string `json:"filteredOutFields"`
CreatedFields []string `json:"createdFields"`
}
type ListSubscriber ¶
type ListUnSubscribeRequest ¶
type ListUnSubscribeRequest struct {
ListId int64 `json:"listId"`
Subscribers []ListUnSubscriber `json:"subscribers"`
CampaignId int64 `json:"campaignId"`
ChannelUnsubscribe bool `json:"channelUnsubscribe"`
}
type ListUnSubscribeResponse ¶
type ListUnSubscribeResponse struct {
SuccessCount int64 `json:"successCount"`
FailCount int64 `json:"failCount"`
FailedUpdates FailedUpdates `json:"failedUpdates"`
FilteredOutFields []string `json:"filteredOutFields"`
CreatedFields []string `json:"createdFields"`
}
type ListUnSubscriber ¶
type ListsResponse ¶
type ListsResponse struct {
Lists []List `json:"lists"`
}
type MessageType ¶
type MessageTypeResponse ¶
type MessageTypeResponse struct {
MessageTypes []MessageType `json:"messageTypes"`
}
type PostResponse ¶
type TriggerCampaignRequest ¶
type TriggerCampaignRequest struct {
AllowRepeatMarketingSends *bool `json:"allowRepeatMarketingSends,omitempty"`
CampaignId int64 `json:"campaignId"`
DataFields map[string]any `json:"dataFields,omitempty"`
ListIds []int64 `json:"listIds,omitempty"`
SuppressionListIds []int64 `json:"suppressionListIds,omitempty"`
}
type UserFieldsResponse ¶
type UserForgottenEmailsResponse ¶
type UserForgottenEmailsResponse struct {
HashedEmails []string `json:"hashedEmails"`
}
type UserRequest ¶
type UserRequest struct {
Email string `json:"email,omitempty"`
UserId string `json:"userId"`
DataFields map[string]interface{} `json:"dataFields,omitempty"`
// Whether a new user should be created if the request includes
// a userId that doesn't yet exist in the Iterable project.
// Only respected in API calls for email-based projects.
// Defaults to false.
PreferUserId bool `json:"preferUserId"`
// Merge top-level objects instead of overwriting them.
// For example, if a user profile has data {"mySettings":{"mobile":true}}
// and the request has data {"mySettings":{"email":true}},
// merging results in {"mySettings":{"mobile":true,"email":true}}.
// Defaults to false.
MergeNestedObjects *bool `json:"mergeNestedObjects,omitempty"`
// Whether new fields should be ingested and added to the schema.
// Defaults to project's setting to allow or drop unrecognized fields.
CreateNewFields *bool `json:"createNewFields,omitempty"`
}
type UserResponse ¶
type UserResponse struct {
User User `json:"user"`
}
type UserSentMessage ¶
type UserSentMessagesRequest ¶
type UserSentMessagesResponse ¶
type UserSentMessagesResponse struct {
Messages []UserSentMessage `json:"messages"`
}
type UserUpdateEmailRequest ¶
type UserUpdateSubscriptionsRequest ¶
type UserUpdateSubscriptionsRequest struct {
Email string `json:"email,omitempty"`
UserId string `json:"userId,omitempty"`
EmailListIds []int64 `json:"emailListIds,omitempty"`
UnsubscribedChannelIds []int64 `json:"unsubscribedChannelIds,omitempty"`
UnsubscribedMessageTypeIds []int64 `json:"unsubscribedMessageTypeIds,omitempty"`
SubscribedMessageTypeIds []int64 `json:"subscribedMessageTypeIds,omitempty"`
CampaignId int64 `json:"campaignId,omitempty"`
TemplateId int64 `json:"templateId,omitempty"`
}
Click to show internal directories.
Click to hide internal directories.